@@ -46,10 +46,10 @@
 #'
 #' @examples
 #' X <- replicate(4,rnorm(1000))
-#' twonn_decimated(X,,method = "proportions",
+#' twonn_decimation(X,,method = "proportions",
 #'                 proportions = c(1,.5,.2,.1,.01))
 #'
-twonn_decimated <- function(X,
+twonn_decimation <- function(X,
                             method = c("steps", "proportions"),
                             steps = 0,
                             proportions = 1,
